@@ -38,8 +38,9 @@ from openmolar.dbtools.plan_data import PlanData
 from openmolar.dbtools.est_logger import EstLogger
 from openmolar.dbtools import estimates as db_estimates
 
-from openmolar.dbtools.queries import \
-    PATIENT_QUERY_FIELDS, PATIENT_QUERY, FUTURE_EXAM_QUERY, PSN_QUERY, FAMILY_COUNT_QUERY
+from openmolar.dbtools.queries import (
+    PATIENT_QUERY_FIELDS, PATIENT_QUERY, FUTURE_EXAM_QUERY,
+    PSN_QUERY, FAMILY_COUNT_QUERY, QUICK_MED_QUERY)
 
 LOGGER = logging.getLogger("openmolar")
 
@@ -80,10 +81,6 @@ exemptionTableAtts = ('exemption', 'exempttext')
 bpeTableAtts = ('bpedate', 'bpe')
 bpeTableVals = (nullDate, '', ())
 
-mnhistTableAtts = ('chgdate', 'ix', 'note')
-
-notesTableAtts = ('lineno', 'line')
-
 mouth = ['ul8', 'ul7', 'ul6', 'ul5', 'ul4', 'ul3', 'ul2', 'ul1',
          'ur1', 'ur2', 'ur3', 'ur4', 'ur5', 'ur6', 'ur7', 'ur8',
          'lr8', 'lr7', 'lr6', 'lr5', 'lr4', 'lr3', 'lr2', 'lr1',
@@ -133,7 +130,7 @@ class patient(object):
         self.pd1 = None
         self.pd2 = None
         self.pd3 = None
-        self.pd4 = None
+        self.pd4 = None  # this field is no longer used (last treatment date)
         self.pd5 = None
         self.pd6 = None
         self.pd7 = None
@@ -218,11 +215,6 @@ class patient(object):
         self.transfer = 0
         self.pstatus = None
 
-        # TABLE 'mnhist'#######
-        self.chgdate = nullDate   # date 	YES 	 	None
-        self.ix = 0  # tinyint(3) unsigned 	YES 	 	None
-        self.note = ''  # varchar(60) 	YES 	 	None
-
         self.estimates = []
 
         # from userdata
@@ -235,8 +227,8 @@ class patient(object):
         self.bpedate = nullDate
         self.chartdate = nullDate
         self.notes_dict = {}
-        self.MH = ()
         self.MEDALERT = False
+        self.mh_chkdate = None
         self.HIDDENNOTES = []
         self.chartgrid = {}
         self._fee_table = None
@@ -248,6 +240,7 @@ class patient(object):
         self._most_recent_daybook_entry = None
         self._has_exam_booked = None
         self._previous_surnames = None
+        self.monies_reset = False
 
         if self.serialno == 0:
             return
@@ -299,15 +292,11 @@ class patient(object):
 
         self.getNotesTuple()
 
-        query = 'select drnm,adrtel,curmed,oldmed,allerg,heart,lungs,' +\
-            'liver,kidney,bleed,anaes,other,alert,chkdate from mednotes' +\
-            ' where serialno=%s'
-        cursor.execute(query, (self.serialno,))
-
-        self.MH = cursor.fetchone()
-        if self.MH is not None:
-            self.MEDALERT = self.MH[12]
-
+        cursor.execute(QUICK_MED_QUERY, (self.serialno,))
+        try:
+            self.MEDALERT, self.mh_chkdate = cursor.fetchone()
+        except TypeError:
+            pass
         cursor.close()
         # db.close()
 
@@ -567,6 +556,7 @@ class patient(object):
                 self.chartgrid[pos] = decidmouth[mouth.index(pos)]
 
     def apply_fees(self):
+        LOGGER.debug("Applying Fees")
         if "N" in self.cset:
             self.money0 = self.dbstate.money0 + self.fees_accrued
         else:
@@ -618,29 +608,39 @@ class patient(object):
 
     def resetAllMonies(self):
         '''
-        zero's everything except money11 (bad debt)
+        gets money1 and money 0 from apply_fees,
+        then equalises money3 and money2 accordingly.
+        zero's everything else
+        money11 (bad debt) is left unaltered.
         '''
-        self.money0 = 0
-        self.money1 = 0
-        self.money9 = 0
-        self.money10 = 0
-        self.money2 = 0
-        self.money3 = 0
-        self.money8 = 0
-
         self.dbstate.money0 = 0
         self.dbstate.money1 = 0
+        self.monies_reset = True
+
+        self.money0 = 0
+        self.money1 = 0
+        self.apply_fees()
+        self.money9 = 0
+        self.money10 = 0
+        self.money2 = self.money0
+        self.money3 = self.money1
+        self.money8 = 0
 
     def nhs_claims(self, completed_only=True):
         claims = []
         for est in self.estimates:
             if (est.csetype.startswith("N") and
                (not completed_only or est.completed == 2)
-                    ):
+                ):
                 claims.append(est)
         return claims
 
-    def addHiddenNote(self, ntype, note="", attempt_delete=False):
+    def addHiddenNote(
+        self,
+        ntype,
+     note="",
+     attempt_delete=False,
+     one_only=False):
         '''
         re-written for schema 1.9
         '''
@@ -693,6 +693,10 @@ class patient(object):
             except ValueError:
                 self.HIDDENNOTES.append(HN)
 
+        if one_only:
+            while self.HIDDENNOTES.count(HN) > 1:
+                self.HIDDENNOTES.remove(HN)
+
     def clearHiddenNotes(self):
         self.HIDDENNOTES = []
 
@@ -701,6 +705,12 @@ class patient(object):
         self.billct += 1
         self.billtype = tone
 
+    def reset_billing(self):
+        if self.fees == 0:
+            self.billdate = None
+            self.billct = None
+            self.billtype = None
+
     def treatmentOutstanding(self):
         return (self.treatment_course and
         self.treatment_course.has_treatment_outstanding)
@@ -771,10 +781,9 @@ class patient(object):
         these are what is copied over into pt.dbstate
         '''
         return (patient_query_atts +
-            exemptionTableAtts + bpeTableAtts + mnhistTableAtts +
-            clinical_memos + (
+            exemptionTableAtts + bpeTableAtts + clinical_memos + (
                 "fees", "estimate_charges", "serialno", "estimates",
-            "appt_prefs", "treatment_course", "chartgrid"))
+                "appt_prefs", "treatment_course", "chartgrid"))
 
     @property
     def USER_CHANGEABLE_ATTRIBUTES(self):
@@ -881,6 +890,11 @@ class patient(object):
                 if tx_hash == hash_:
                     yield est
 
+    @property
+    def address_tuple(self):
+        return (self.sname, self.addr1, self.addr2,
+                self.addr3, self.town, self.county,
+                self.pcde, self.tel1)
 
 if __name__ == "__main__":
     '''testing stuff'''
