@@ -76,8 +76,11 @@ class chartLineEdit(QtGui.QLineEdit):
         deletes all props
         '''
         new_props = []
+        found = False
         for ex_prop in self.propListFromText():
-            if ex_prop.upper() != prop:
+            if not found and ex_prop.upper() == prop.upper():
+                found = True
+            else:
                 new_props.append(ex_prop)
         self.updateFromPropList(new_props)
 
@@ -377,12 +380,12 @@ class ToothPropertyEditingWidget(QtGui.QWidget, Ui_toothProps.Ui_Form):
         '''
         comments combobox has been nav'd
         '''
-        if arg == _("ADD COMMENTS"):
+        if _("ADD COMMENTS") in arg:
             return
-        elif arg == _("DELETE COMMENTS"):
+        elif arg == _("DELETE ALL COMMENTS"):
             self.lineEdit.deleteComments()
         else:
-            newComment = "%s" % arg.replace(" ", "_")
+            newComment = "!%s" % arg.replace(" ", "_")
             self.lineEdit.addItem(newComment)
 
         self.comments_comboBox.setCurrentIndex(0)
